@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * with this program. If not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *   Daniel P. Berrange <berrange@redhat.com>
@@ -286,7 +285,8 @@ static int osinfo_db_export_create_file(const gchar *prefix,
     g_free(abspath);
     g_free(relpath);
     g_free(entpath);
-    g_object_unref(info);
+    if (info)
+        g_object_unref(info);
     if (err)
         g_error_free(err);
     return ret;
@@ -537,7 +537,7 @@ gint main(gint argc, gchar **argv)
     if (custom)
         locs++;
     if (locs > 1) {
-        g_printerr(_("Only one of --user, --local, --system & --dir can be used"));
+        g_printerr(_("Only one of --user, --local, --system & --dir can be used\n"));
         goto error;
     }
 
